<?php
/**
 * shale Customizer functionality
 * 
 * @subpackage shale
 * @since shale 1.0
 */

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function shale_customize_preview_js() {
	wp_enqueue_script( 'shale_customizer', get_template_directory_uri() . '/assets/js/theme-customizer.js', array( 'customize-preview' ), '1.0.0', true );
}
add_action( 'customize_preview_init', 'shale_customize_preview_js' );

/**
 * shale Options.
 */
function shale_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	// Primary/Link Color
	$wp_customize->add_setting( 'primary_color', array(
		'default'           => '#842b43',
		'sanitize_callback' => 'sanitize_hex_color'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color', array(
		'label'       => __( 'Accent/Link Color', 'shale' ),
		'section'     => 'colors',
		'description' => __( 'The primary link/button color for the content area.', 'shale' )
	) ) );

	// Create social URL section
	
	$wp_customize->add_section( 'shale_social_urls' , array(
    'title'      => __('Social Urls','shale'),
    'priority'   => 85,
	) );

	// Facebook URL
	$wp_customize->add_setting( 'facebook_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'facebook_url', array(
		'label'       => __( 'Facebook Url', 'shale' ),
		'section'     => 'shale_social_urls',
	) ) );

	// Twitter URL
	$wp_customize->add_setting( 'twitter_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'twitter_url', array(
		'label'       => __( 'Twitter Url', 'shale' ),
		'section'     => 'shale_social_urls',
	) ) );

	// Pinterest URL
	$wp_customize->add_setting( 'pinterest_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'pinterest_url', array(
		'label'       => __( 'Pinterest Url', 'shale' ),
		'section'     => 'shale_social_urls',
	) ) );

 // Create Flexslider section
	
	$wp_customize->add_section( 'shale_slider_settings' , array(
    'title'      => __('Slider','shale'),
    'priority'   => 80,
    'description' => __( 'The homepage slider. Will display the 10 most recent sticky posts.', 'shale' )
	) );

	$wp_customize->add_setting( 'enable_slider', array(
		'default'           => false,
		'sanitize_callback' => 'shale_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'enable_slider', array(
		'label'       => __( 'Check to enable/disable slider', 'shale' ),
		'section'     => 'shale_slider_settings',
		'type'			  => 'checkbox'
	) );

	$wp_customize->add_setting( 'remove_stickies', array(
		'default'           => false,
		'sanitize_callback' => 'shale_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'remove_stickies', array(
		'label'       => __( 'Check to remove Sticky posts from main query when slider is enabled', 'shale' ),
		'section'     => 'shale_slider_settings',
		'type'			  => 'checkbox'
	) );

	// Footer Message
	
	$wp_customize->add_section( 'shale_footer_settings' , array(
    'title'      => __('Footer Message','shale'),
    'priority'   => 80,
	) );

	$wp_customize->add_setting( 'footer_message', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'footer_message', array(
		'label'       => __( 'Footer Message', 'shale' ),
		'section'     => 'shale_footer_settings',
		'type' 				=> 'textarea'
	) ) );

}
add_action( 'customize_register', 'shale_customize_register' );

/* Sanitize Callbacks */

function shale_sanitize_checkbox( $input ) {
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

/* Add New CSS */

function shale_customize_css()
{
	?>
		<style type="text/css">

		/* Primary Color */
		a,
		.entry-author a,
		.footer-widgets .widget .widget-title,
		.footer-widgets .widget ul li.recentcomments:before,
		.footer-widgets .widget ul li:before,
		.right-sidebar .widget a:hover,
		.footer-widgets .widget a:hover { color:<?php echo esc_html(  get_theme_mod('primary_color', '#770022') ); ?> }

		.site-title,
		input[type="submit"],
		.pagination .page-numbers:hover,
		.site-nav ul li ul li a:hover,
		.show-nav .site-nav ul li a:hover,
		.social-links .social-icon .fa:hover,
		.sticky-message,
		.flexslider .flex-control-nav li a.flex-active { background-color:<?php echo esc_html( get_theme_mod('primary_color', '#770022') ); ?> }

		.right-sidebar { border-top-color:<?php echo esc_html( get_theme_mod('primary_color', '#770022') ); ?> }

		</style>
	<?php
}
add_action( 'wp_head', 'shale_customize_css');