<?php
/**
 * Custom template tags for shale
 * 
 */

/**
 * Custom Logo
 */

function shale_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) && function_exists( 'has_custom_logo' ) ) { 
		if ( has_custom_logo() ): ?>
			<div class='site-logo'>
				<?php the_custom_logo() ?>
			</div> 
	 	<?php
	 	elseif ( is_front_page() && is_home() ) : ?>
			<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php esc_html( bloginfo( 'name' ) ); ?></a></h1>
		<?php else : ?>
			<span class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php esc_html( bloginfo( 'name' ) ); ?></a></span>
		<?php endif; 
	}
}

/* How about an author bio template tag? Let's do it! */

if ( ! function_exists( 'shale_author_bio' ) ) {
	function shale_author_bio() {
		?>
		<div class="author-info clearfix">
			<div class="author-image">
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo get_avatar( get_the_author_meta('user_email'), '100', '' ); ?></a>
			</div>   
			<div class="author-bio">
				<h4><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php esc_html( the_author() ); ?></a></h4>
				<p><?php esc_html( the_author_meta('description') ); ?></p>
			</div>
		</div>
		<?php
	}
}

/**
 * Custom post navigation template tag for single posts & pages
 * Appears in content-single.php
 */

function shale_post_nav() {
  ?>
  <nav class="post-navigation clearfix"> 
  	<span class="post-nav-link previous-post">
			<?php previous_post_link('%link', '<span class="previous-post-label">' . __( '< ', 'shale' ) . '</span>%title' ); ?>
		</span>
		<span class="post-nav-link next-post">
			<?php next_post_link('%link', '%title<span class="next-post-label">' . __( ' >', 'shale' ) . '</span>' ); ?>
		</span>
	</nav>
	<?php
}

/**
 * Social Icons. Used in header.php, probably!
 */

function shale_social_icon( $site ) {

  $url = get_theme_mod( $site . '_url' );

  if ( $url != NULL) {
    echo '<a class="social-icon" title="' . esc_html( $site ) . '" href="' . esc_url( $url ) . '"><i class="fa fa-' . esc_html( $site ) . '"></i></a>';
  } else {
  	return NULL;
  }
}

/** 
 * Flexslider template tag
 */

function shale_flexslider() {

	$enabled = get_theme_mod( 'enable_slider' );
	$stickies = get_option( 'sticky_posts' );
	$count = count( $stickies );

	$args = array(
	    'post__in' => $stickies,
	    'posts_per_page' => 10,
	    'post_type' => 'post',
	    'nopaging' => true
	    );

	$query = new WP_Query( $args );

	if ( $enabled ) {
		if ( $count > 0 ) : 
			echo '<div id="slider"><div class="slider-inner">';
			  echo '<div class="flexslider"><ul class="slides">';

		    	while ( $query->have_posts() ) : $query->the_post();
			      
			      echo '<li>';
			      
			      if ( (function_exists( 'has_post_thumbnail' )) && ( has_post_thumbnail() ) ) :
			        echo '<a href="'.  esc_url( get_permalink() ) .'">' . get_the_post_thumbnail( '', 'slider-image' ) . '</a>';
			      endif;

		        echo '<div class="slider-caption">';
		            if ( get_the_title() != '' ) echo '<a href="'.  esc_url( get_permalink() ) .'"><h2 class="slider-title">'. esc_html( get_the_title() ) .'</h2></a>';
		            if ( get_the_excerpt() != '' ) echo '<div class="slider-excerpt">' . esc_html( get_the_excerpt() ) .'</div>';
		        echo '</div>';
		        echo '</li>';
	        endwhile;
			  echo '</ul></div>';
			echo '</div></div>';
		endif;
	}
}